@@ -410,8 +410,13 @@ class Execute_Device():
 			except:
 				print(f"DeviceType not detected for {ip}")
 			if self.dev is not None and self.dev.dtype == 'cisco_ios': 
-				sleep(65)
-			self.execute(ip)
+				try:
+					self.execute(ip)
+				except:
+					sleep(65)
+					self.execute(ip)
+			else:
+				self.execute(ip)
 
 
 	def check_ping(self, ip):
@@ -442,7 +447,8 @@ class Execute_Device():
 		try:
 			self.dev = DeviceType(dev_ip=ip, 
 				un=self.auth['un'], 
-				pw=self.auth['pw'])
+				pw=self.auth['pw'],
+			)
 			return self.dev
 		except Exception as e:
 			print(f'{ip}: {e}')
